@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015 Aurimas Cernius
+ * Copyright (C) 2010-2016 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -100,7 +100,7 @@ namespace gnote {
       if (find_depth_tag(select_start))
         select_start.set_line_offset(2);
 
-      if (select_start.begins_tag(tag) || select_start.has_tag(tag)) {
+      if(is_active_tag(tag)) {
         remove_tag(tag, select_start, select_end);
       }
       else {
@@ -219,6 +219,12 @@ namespace gnote {
   bool NoteBuffer::is_active_tag(const std::string & tag_name)
   {
     Glib::RefPtr<Gtk::TextTag> tag = get_tag_table()->lookup(tag_name);
+    return is_active_tag(tag);
+  }
+
+
+  bool NoteBuffer::is_active_tag(const Glib::RefPtr<Gtk::TextTag> & tag)
+  {
     Gtk::TextIter iter, select_end;
 
     if (get_selection_bounds (iter, select_end)) {
@@ -227,7 +233,18 @@ namespace gnote {
       if (find_depth_tag(iter)) {
         iter.forward_chars(2);
       }
-      return iter.begins_tag(tag) || iter.has_tag(tag);
+      if(iter.begins_tag(tag) || iter.has_tag(tag)) {
+        // consider tag active only if it applies to the entire selection
+        if (iter.forward_to_tag_toggle(tag)) {
+          return select_end <= iter;
+        }
+        else {
+          // probably reached the end of note
+          return true;
+        }
+      }
+
+      return false;
     } 
     else {
       return (find(m_active_tags.begin(), m_active_tags.end(), tag) != m_active_tags.end());
@@ -248,7 +265,7 @@ namespace gnote {
 
     Glib::RefPtr<Gtk::TextTag> depth = find_depth_tag(iter);
 
-    return (bool)depth;
+    return depth;
   }
 
 
@@ -1341,7 +1358,7 @@ namespace gnote {
       if (iter.get_line() < buffer->get_line_count() - 1) {
         Gtk::TextIter next_line = buffer->get_iter_at_line(iter.get_line()+1);
         next_line_has_depth =
-          (bool)NoteBuffer::Ptr::cast_static(buffer)->find_depth_tag (next_line);
+          NoteBuffer::Ptr::cast_static(buffer)->find_depth_tag (next_line);
       }
 
       bool at_empty_line = iter.ends_line () && iter.starts_line ();
@@ -1576,7 +1593,7 @@ namespace gnote {
               NoteBuffer::Ptr note_buffer = NoteBuffer::Ptr::cast_dynamic(buffer);
               // Do not insert bullet if it's already there
               // this happens when using double identation in bullet list
-              if(!note_buffer->find_depth_tag(apply_start)) {
+              if(note_buffer->find_depth_tag(apply_start) == 0) {
                 note_buffer->insert_bullet (apply_start, depth_tag->get_depth(), depth_tag->get_direction());
                 buffer->remove_all_tags (apply_start, apply_start);
                 offset += 2;
